<template>
  <div class="model-container">
    <el-card class="selection-tree" :body-style="bodyStyle">
      <div class="button-group">
        <div
          class="button"
          :class="{active_style: currentType == 'crew'}"
          @click="changeType('crew')"
        >
          <i class="icon-fengdianchang"></i>
          机组
        </div>
        <div
          class="button"
          :class="{active_style: currentType == 'model'}"
          @click="changeType('model')"
        >
          <i class="icon-pingtaishuliang"></i>
          模型
        </div>
      </div>
      <div class="tree-list-con">
        <el-input
          class="search-input"
          placeholder="请输入关键字搜索"
          v-model.lazy="filterText"
        >
        </el-input>
        <div class="tree-content">
          <!-- <el-scrollbar> -->
          <el-tree
            class="editScroll"
            ref="tree1"
            node-key="id"
            highlight-current
            :data="crew"
            :props="crewProps"
            @node-click="handleNodeClick"
            :filter-node-method="filterNode"
            :currentNodeKey="currentNodeKey1"
            v-if="currentType == 'crew'"
          >
            <span class="custom-tree-node" slot-scope="{node}">
              <span>
                <i class="el-icon-menu tree-icon"></i>{{ node.label }}
              </span>
            </span>
          </el-tree>
          <el-tree
            class="editScroll"
            ref="tree2"
            node-key="id"
            highlight-current
            :data="model"
            :props="modelProps"
            :currentNodeKey="currentNodeKey2"
            @node-click="handleNodeClick"
            :filter-node-method="filterNode"
            v-else
          >
            <span class="custom-tree-node" slot-scope="{node}">
              <span>
                <i class="el-icon-menu tree-icon"></i>{{ node.label }}
              </span>
            </span>
          </el-tree>
          <!-- </el-scrollbar> -->
        </div>
      </div>
    </el-card>
    <div
      class="model-list-container"
      v-if="currentType == 'crew' && modelList.length"
    >
      <el-scrollbar class="editScroll">
        <div class="model-list">
          <el-card
            class="model-item-container"
            body-style="padding:0;height:100%"
            v-for="(item, index) in modelList"
            :key="index"
          >
            <div class="model-status">
              <!-- <div class="status"> -->
              <div style="width:15px;heigth:10px;">
                <div
                  class="status-round"
                  :class="{
                    'model-item-danger': item.taskStatus == 'NONE',
                    'model-item-warning': item.taskStatus == 'PAUSED',
                    'model-item-success': item.taskStatus == 'NORMAL'
                  }"
                ></div>
              </div>
              <div class="task-name">
                {{ item.taskName }}
              </div>
              <!-- </div> -->
              <div class="model-rate" v-if="item.taskRate && item.taskRateUnit">
                <div>
                  <i class="el-icon-time icon-size"></i>
                  <span
                    >{{ item.taskRate }}
                    {{ item.taskRateUnit | taskRateUnit }}</span
                  >
                </div>
              </div>
            </div>
            <div class="model-content">
              <div class="model-bg">
                <div class="model-text">
                  {{ item.modelClass }}
                </div>
                <div class="model-img"></div>
              </div>
              <div class="name-border">
                {{ item.modelName }}
              </div>
              <div class="model-detail" @click="handleHistory(item)">
                <i class="el-icon-more"></i>
              </div>
            </div>
          </el-card>
        </div>
      </el-scrollbar>
    </div>
    <el-card
      class="model-list-empty"
      shadow="never"
      :body-style="bodyStyle2"
      v-if="currentType == 'crew' && !modelList.length"
    >
      <div class="model-empty-content">
        <i class="icon-empty" style="font-size: 100px"></i>
        <div>暂无模型</div>
      </div>
    </el-card>
    <el-card
      class="model-crew-list"
      shadow="never"
      :body-style="bodyStyle3"
      v-if="currentType == 'model'"
    >
      <div class="model-crew-head">
        {{ modelTitle }}
      </div>
      <div class="model-crew-content">
        <div class="dialog-body-border" v-if="modelResult.length">
          <div style="width:100%;height:40px;">
            <span style="font-size:14px;color:#c0c4cc;margin-right:5px"
              >调度时间</span
            >
            <el-date-picker
              v-model="dateTime"
              type="datetimerange"
              unlink-panels
              range-separator="—"
              start-placeholder="请选择开始日期"
              end-placeholder="请选择结束日期"
              value-format="yyyy-MM-dd HH:mm:ss"
              style="width:350px"
            >
            </el-date-picker>
            <el-button
              style="margin-left: 10px"
              size="small"
              type="primary"
              icon="el-icon-search"
              @click="loadData"
              >搜索</el-button
            >
          </div>
          <el-table
            :data="data"
            stripe
            style="width: 100%"
            height="calc(100% - 70px)"
          >
            <el-table-column
              :scoped-slot="item.paramWidth ? null : renderHeader"
              v-for="item of modelResult"
              :key="item.paraCode"
              :prop="item.paramCode"
              :label="item.paramName"
              :min-width="item.paramWidth"
              :show-overflow-tooltip="true"
              align="center"
            ></el-table-column>
          </el-table>
          <div style="width:100%;margin-top:5px">
            <el-pagination
              style="float:right"
              small
              @size-change="handleSizeChange"
              @current-change="handleCurrentChange"
              :current-page="currentPage"
              :pager-count="11"
              :page-sizes="[10, 20, 50, 100, 200, 300, 500]"
              :page-size="50"
              layout="total, sizes, prev, pager, next, jumper"
              :total="total"
            >
            </el-pagination>
          </div>
        </div>
        <div v-else class="dialog-body-border bgcolor">
          <div>请联系管理员，配置模型出参数据</div>
        </div>
      </div>
    </el-card>
    <ModelHistory ref="modelHistory"></ModelHistory>
  </div>
</template>
<script>
import ModelHistory from './modules/ModelHistory.vue'
export default {
  components: {
    ModelHistory
  },
  name: 'hybrid-model-presentation',
  filters: {
    taskRateUnit(data) {
      let text = ''
      switch (data) {
        case 's':
          text = '秒'
        case 'm':
          text = '分钟'
          break
        case 'h':
          text = '小时'
          break
        case 'd':
          text = '天'
          break
        case 'w':
          text = '周'
          break
        case 'M':
          text = '月'
          break
        case 'Y':
          text = '年'
          break
        default:
          break
      }
      return text
    }
  },
  data() {
    return {
      bodyStyle: {
        padding: '10px',
        height: 'calc(100% - 20px)'
      },
      bodyStyle2: {
        padding: '10px',
        height: 'calc(100% - 20px)',
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center'
      },
      bodyStyle3: {
        padding: '0',
        height: '100%'
      },
      currentType: 'crew',
      crew: [],
      model: [],
      currentNodeKey1: '',
      currentNodeKey2: '',
      crewProps: {
        children: 'children',
        label: 'treeLabel'
      },
      modelProps: {
        children: 'children',
        label: 'treeLabel'
      },
      modelList: [],
      modelTitle: '模型名称',
      tableData: [], //模型数据列表
      searchDate: '',
      filterText: '',
      currentPage: 1, //当前页
      pageSize: 50, //每页多少条
      total: 0, //总条数
      data: [],
      dateTime: [],
      fanCode: '', //机组编号
      modelId: '', //模型ID
      modelResult: [] //执行结果
    }
  },
  watch: {
    filterText(val) {
      if (this.currentType == 'crew') {
        this.$refs.tree1.filter(val)
      } else {
        this.$refs.tree2.filter(val)
      }
    }
  },
  created() {
    this.initCrewList()
    this.initModelList()
  },
  mounted() {
    this.$nextTick(() => {
      this.$refs.tree1.setCurrentKey(this.currentNodeKey1)
    })
  },
  methods: {
    renderHeader(h, {column}) {
      // console.log(column)
      if (column.label.length && column.label.length < 4) {
        column.minWidth = 50
      } else {
        column.minWidth = column.label.length * 16
      }
      return h(
        'div',
        {
          class: 'table-header'
        },
        [column.label]
      )
    },
    filterNode(value, data) {
      console.log(data, value, '123')
      if (!value) return true
      return data.treeLabel.indexOf(value) !== -1
    },
    //切换机组和模型按钮
    changeType(val) {
      this.currentType = val
      this.$nextTick(() => {
        if (this.currentType == 'model') {
          this.$refs.tree2.setCurrentKey(this.currentNodeKey2)
        } else {
          this.$refs.tree1.setCurrentKey(this.currentNodeKey1)
        }
      })
    },
    handleNodeClick(data) {
      // console.log(data, 'data')
      if (this.currentType == 'model') {
        this.currentNodeKey2 = data.id
        this.modelTitle = data.modelName
        this.currentPage = 1
        this.pageSize = 50
        this.total = 0
        this.modelResult = []
        this.loadData()
      } else {
        this.loadCrewModel(data)
      }
    },
    loadCrewModel(node) {
      let query = {
        url: '${cssc}/biz/model/modelInfo/v1/modelFan/queryModelByFan',
        method: 'POST',
        headers: {
          'Content-type': 'application/x-www-form-urlencoded'
        },
        data: this.qs.stringify({
          fanCode: node.fanCode,
          fanId: node.id,
          modelCategory: 1
        })
      }
      this.$http.request(query).then(res => {
        this.modelList = res.data
      })
    },
    initCrewList() {
      let query = {
        sorter: [{direction: 'ASC', property: 'fanCode'}]
      }
      this.$http.post('${cssc}/biz/base/fanInfo/v1/list', query).then(
        resp => {
          if (resp.data) {
            this.crew = resp.data
            if (this.crew.length) {
              this.crew = this.crew.map(item => {
                item.treeLabel = item.fanCode
                return item
              })
              this.currentNodeKey1 = this.crew[0].id
              this.$nextTick(() => {
                this.$refs.tree1.setCurrentKey(this.currentNodeKey1)
              })
              this.loadCrewModel(this.crew[0])
            }
          }
        },
        error => {
          reject(error)
        }
      )
    },
    initModelList() {
      let query = {
        sorter: [{direction: 'ASC', property: 'modelName'}]
      }
      this.$http.post('${cssc}/biz/model/modelInfo/v1/list', query).then(
        resp => {
          if (resp.data) {
            this.model = resp.data
            this.modelTitle = resp.data[0].modelName
            if (this.model.length) {
              this.model = this.model.map(item => {
                item.treeLabel = item.modelName
                return item
              })
              this.currentNodeKey2 = this.model[0].id
            }
          }
        },
        error => {
          reject(error)
        }
      )
    },
    handleHistory(item) {
      this.$refs.modelHistory.open(item)
    },
    loadData() {
      let param = {
        pageBean: {
          page: this.currentPage,
          pageSize: this.pageSize,
          total: this.total
        },
        querys: [],
        sorter: [
          {
            direction: 'DESC',
            property: 'scheduler_time_'
          },
          {
            direction: 'ASC',
            property: 'fan_code_'
          }
        ]
      }
      let dateQuerys = [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'scheduler_time_',
          relation: 'AND',
          value: this.dateTime
        }
      ]
      if (this.dateTime && this.dateTime.length) {
        if (param.querys && param.querys.length) {
          param.querys.push(...dateQuerys)
        } else {
          param.querys = dateQuerys
        }
      }
      this.$http
        .post(
          '${cssc}/biz/model/modelInfo/v1/modelResult/sliceQueryModelResult?modelId=' +
            this.currentNodeKey2,
          param
        )
        .then(
          res => {
            let resp = res.data
            let rows = resp.rows
            this.data = rows
            this.currentPage = resp.page
            this.pageSize = resp.pageSize
            this.total = resp.total

            let param2 = {
              pageBean: {
                page: 1,
                pageSize: 50,
                total: 0
              },
              querys: [
                {
                  group: 'main',
                  operation: 'EQUAL',
                  parentGroup: '',
                  property: 'modelId',
                  relation: 'AND',
                  value: this.currentNodeKey2
                },
                {
                  group: 'main',
                  operation: 'EQUAL',
                  parentGroup: '',
                  property: 'paramType',
                  relation: 'AND',
                  value: 'result'
                }
              ],
              sorter: [
                {
                  direction: 'ASC',
                  property: 'sn'
                }
              ]
            }
            this.$http
              .post(
                '${cssc}/biz/model/modelInfo/v1/modelParams/queryParamByModel',
                param2
              )
              .then(res => {
                this.modelResult = res.data
              })
          },
          error => {
            reject(error)
          }
        )
    },
    handleSizeChange(val) {
      this.pageSize = val
      this.loadData()
    },
    handleCurrentChange(val) {
      this.currentPage = val
      this.loadData()
    }
  }
}
</script>
<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';
$table-tr: #fff2cc;
.model-container {
  width: 100%;
  height: 100%;
  display: flex;
  .selection-tree {
    width: 280px;
    margin-right: 10px;
    text-align: center;
    /deep/ .icon-fengdianchang,
    /deep/ .icon-pingtaishuliang {
      margin-right: 6px;
    }
    .tree-list-con {
      height: calc(100% - 42px);
      margin-top: 10px;
      border: 1px solid rgba($--color-primary, 0.4);
    }
    .tree-content {
      height: calc(100% - 56px);
      margin-bottom: -8px;
    }
    .search-input {
      margin: 8px auto;
      width: 90%;
    }
    .tree-icon {
      margin-right: 6px;
      color: $--color-primary;
    }
  }
  .model-crew-list {
    width: calc(100% - 220px);
    .model-crew-head {
      background: $--color-primary;
      color: #fff;
      padding: 10px;
    }
    .model-crew-content {
      width: 100%;
      height: calc(100% - 36px);
      box-sizing: border-box;
      display: flex;
      padding: 0 10px;
      padding-top: 10px;
    }
    .model-table {
      width: calc(100% - 200px);
      width: 100%;
      height: 100%;
      padding: 10px 0;
    }
    .serach-panle {
      margin: 10px 0;
      display: flex;
      justify-content: start;
      align-items: center;
    }
    /deep/ .el-table th {
      color: $--color-text-primary;
    }
  }
  .model-list-container {
    width: calc(100% - 220px);
    .model-list {
      display: flex;
      justify-content: start;
      align-items: center;
      flex-wrap: wrap;
      box-sizing: border-box;
    }
    .model-item-container {
      width: calc(25% - 10px);
      height: 300px;
      margin-bottom: 10px;
      margin-right: 10px;
    }
    .model-item-container:nth-of-type(4n) {
      margin-right: 0;
      margin-top: 0;
    }
  }
  .model-list-empty {
    width: calc(100% - 220px);
    height: calc(100% - 2px);
    .model-empty-content {
      color: $--color-text-placeholder;
      i {
        font-size: 100px;
        color: $--color-text-placeholder;
        margin-bottom: 10px;
      }
      text-align: center;
      font-size: 14px;
    }
  }

  /deep/ .el-scrollbar__wrap {
    height: calc(100% + 17px) !important;
  }
  .model-item-header {
    display: flex;
    justify-content: space-between;
    align-items: center;
    background: $--color-primary;
    color: #fff;
    padding: 6px;
  }
  .model-item-body {
    position: relative;
    height: calc(100% - 28px);
  }
  .btn-group {
    width: 100%;
    position: absolute;
    bottom: 10px;
    left: 0;
    display: flex;
    justify-content: space-between;
    align-items: center;
    padding: 0 6px;
    box-sizing: border-box;
  }
  .model-item-content {
    width: 100%;
    height: 100%;
    display: flex;
    justify-content: center;
    align-items: center;
    .model-item-icon {
      font-size: 40px;
      color: rgba($--color-primary, 0.8);
    }
    .el-icon-warning {
      color: rgba($--color-danger, 0.8);
    }
  }
  //未执行
  .model-item-danger {
    background-color: $--color-danger;
  }
  //执行中
  .model-item-warning {
    background-color: $--color-warning;
  }
  //执行完成
  .model-item-success {
    background-color: $--color-success;
  }
  .btn-history {
    cursor: pointer;
  }
  .table-page {
    text-align: right;
    padding: 10px 0;
    /deep/ .el-input__inner {
      height: 23px !important;
      line-height: 23px !important;
    }
  }
}
.editScroll {
  height: 100% !important;
  overflow-x: hidden;
}
.model-status {
  // border: 1px solid red;
  padding: 15px 15px 0;
  height: 30px;
  color: #fff;
  display: flex;
  justify-content: space-between;
  flex-wrap: wrap;
  // align-items: center;
}

.status-round {
  width: 10px;
  height: 10px;
  margin-top: 3px;
  margin-right: 5px;
  border-radius: 50%;
}

.model-rate {
  width: 80px;
  position: relative;
  div {
    position: absolute;
    right: 0;
  }
}
.task-name {
  width: calc(100% - 95px);
  // text-align: center;
}

.model-content {
  height: calc(100% - 45px);
  color: #fff;
  position: relative;
}

.icon-size {
  font-size: 14px;
  color: $--light-active-border;
  padding-right: 5px;
}
.model-img {
  width: 150px;
  height: 150px;
  background: url('../../assets/img/database_icon.png') center / 100% 100%
    no-repeat;
  text-align: center;
}
.model-bg {
  height: 75%;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  text-align: center;
}
.model-text {
  letter-spacing: 0;
  font-size: 18px;
  font-weight: bold;
  // text-shadow: 0px 2px 0px #eef6f8, 0px 10px 10px #07253d;
  background-image: linear-gradient(135deg, #61f5ec, #2aa6ed);
  background-clip: text;
  -webkit-background-clip: text;
  color: transparent;
}
.name-border {
  padding: 0 15px;
  height: 40px;
  text-align: center;
  font-size: 14px;
}
.name-border:hover {
  cursor: default;
}

.model-detail {
  position: absolute;
  bottom: 15px;
  right: 18px;
}
.model-detail:hover {
  cursor: pointer;
}
/deep/ .el-dialog {
  background: transparent;
  border: 1px solid $--light-border;
}
/deep/ .el-dialog__header {
  padding: 14px 25px;
  background: $--table-bgcolor;
  border-bottom: 1px solid $--light-border;
}
/deep/ .el-dialog__title {
  color: #fff;
  font-size: 16px;
}
/deep/ .el-dialog__body {
  padding: 10px 20px 0;
  background: $--table-bgcolor;
}
/deep/ .el-dialog__footer {
  background: $--table-bgcolor;
  border-top: 1px solid $--light-border;
}
/deep/ .el-icon-close:before {
  font-size: 16px;
}
/deep/ .htTable-outer {
  height: calc(100% - 90px) !important;
}
/deep/ .el-input-group__append {
  background-color: $--table-title-bgcolor;
}

/deep/ .el-dialog__footer > div .el-button {
  background: $--color-primary;
  color: #fff;
}
/deep/ .el-icon-search:before,
/deep/ .el-icon-close:before {
  color: #fff;
}
.button-group {
  height: 30px;
  display: flex;
  justify-content: space-between;
}

.button {
  width: calc(50% - 5px);
  background: url('../../assets/img/tab.png') center / 100% 100% no-repeat;
  color: #fff;
  font-weight: bold;
  line-height: 30px;
}
.button:hover {
  cursor: pointer;
  background: url('../../assets/img/tab_active.png') center / 100% 100%
    no-repeat;
  color: $--light-active-border;
}
.active_style {
  background: url('../../assets/img/tab_active.png') center / 100% 100%
    no-repeat;
  color: $--light-active-border;
}
/deep/ .el-divider {
  background: transparent;
}
/deep/ .ht-table-panel {
  height: calc(100% - 10px);
}
/deep/ .el-range-editor--small.el-input__inner,
/deep/ .el-date-editor .el-range-input {
  background-color: $--background-color-secondary;
}
/deep/ .el-range-separator,
/deep/ .el-date-editor .el-range-input {
  color: $--color-text-placeholder;
}
/deep/ .el-table .cell {
  padding-left: 0;
  padding-right: 0;
}
/deep/ .el-table .cell .table-header {
  width: 100% !important;
  box-sizing: border-box;
}
.dialog-body-border {
  height: calc(100% - 10px);
  width: 100%;
}
/deep/ .el-input--mini .el-input__inner {
  height: 22px;
  line-height: 22px;
}

/deep/ .el-table {
  background: $--background-color-secondary;
}
.bgcolor {
  background-color: $--background-color-secondary;
  div {
    color: $--color-info;
    text-align: center;
    padding-top: 200px;
  }
}

/deep/ .is-scrolling-none {
  height: calc(100% - 39px) !important;
}
/deep/ .is-scrolling-left,
/deep/ .is-scrolling-middle,
/deep/ .is-scrolling-right {
  height: calc(100% - 40px) !important;
}
</style>
